%define openssl_certs_dir %{_sysconfdir}/ssl/certs
%define openssl_cert_pem %{_sysconfdir}/ssl/cert.pem

%define commit_date 20170807
%define commit_id 10b278586d2378e25d5cc9463be84c29725aa918
%define short_id %{expand:%%{lua: str='%{commit_id}'; print(str:sub(0, 7))}}

%define admin_trust_dir %{_sysconfdir}/pki/trust
%define package_trust_dir %{_datadir}/pki/trust

Name: ca-certificates
Version: 2_git%{commit_date}.%{short_id}
Release: 6
License: GPL-2.0-or-later
Summary: Utilities for managing TLS certificate stores
Url: https://github.com/openSUSE/ca-certificates
BuildArch: noarch

Source0: https://github.com/openSUSE/ca-certificates/archive/%{commit_id}.zip
Source1: ca-certificates-readme.txt

Requires: p11-kit-trust

Recommends: ca-certificates-mozilla


%description
Utilities for managing and synchronizing TLS (SSL) certificate stores across
various libraries and tools which may use different formats or locations to find
their certificate stores.

%prep
%setup -q -n %{name}-%{commit_id}

sed -i 's|/usr/lib|%{_libdir}|g' update-ca-certificates
sed -i 's|/etc|%{_sysconfdir}|g' update-ca-certificates
sed -i 's|/usr/bin/perl|%{_bindir}/perl|g' update-ca-certificates

sed -i 's|/bin/bash|%{_bindir}/bash|g' *.run
sed -i 's|/var|%{_localstatedir}|g' *.run
# only find exact matches for <trust>
sed -i 's|\<trust\>|%{_bindir}/trust|g' *.run
# fix cadir path
sed -i 's|%{_localstatedir}/lib/ca-certificates/pem|%{_localstatedir}/lib/ca-certificates/openssl|g' openssl.run

# make them orderable
mv java.run 50-java.run
mv openssl.run 50-openssl.run
mv certbundle.run 50-certbundle.run


%install
install -D -m 755 update-ca-certificates %{buildroot}%{_bindir}/update-ca-certificates
install -D -m 644 update-ca-certificates.8 %{buildroot}%{_mandir}/man8/update-ca-certificates.8

mkdir -p %{buildroot}%{_sysconfdir}/ca-certificates/update.d
mkdir -p %{buildroot}%{_libdir}/ca-certificates/update.d

install -D -m 755 50-java.run    %{buildroot}%{_libdir}/ca-certificates/update.d/50-java.run
install -D -m 755 50-openssl.run %{buildroot}%{_libdir}/ca-certificates/update.d/50-openssl.run
install -D -m 755 50-certbundle.run %{buildroot}%{_libdir}/ca-certificates/update.d/50-certbundle.run

mkdir -p %{buildroot}/`dirname %{openssl_certs_dir}`
ln -s  %{_localstatedir}/lib/ca-certificates/openssl %{buildroot}%{openssl_certs_dir}
# symlink to resolve default openssl certfile /QOpenSys/etc/ssl/cert.pem (does not exist)
# to /QOpenSys/var/lib/ca-certificates/ca-bundle.pem
ln -s  %{_localstatedir}/lib/ca-certificates/ca-bundle.pem %{buildroot}%{openssl_cert_pem}


mkdir -p %{buildroot}%{_localstatedir}/lib/ca-certificates

mkdir -p %{buildroot}%{admin_trust_dir}/anchors
mkdir -p %{buildroot}%{admin_trust_dir}/blacklist

cp %{SOURCE1} %{buildroot}%{admin_trust_dir}/README

mkdir -p %{buildroot}%{package_trust_dir}/anchors
mkdir -p %{buildroot}%{package_trust_dir}/blacklist


%pre -p %{_bindir}/bash
# Migrate OpenSSL ssl/certs directory to symlink
if [ "$1" -ne 0 -a -d %{openssl_certs_dir} -a ! -L %{openssl_certs_dir} ]
then
    # Try to remove the directory if it's empty
    rmdir %{openssl_certs_dir} || :
    
    # If we didn't remove the empty directory, copy the pem files
    # to the p11-kit managed trust anchor directory
    if [ -e %{openssl_certs_dir} ]
    then
        mkdir -p %{admin_trust_dir}
    
        for cert in %{openssl_certs_dir}/*.pem
        do
            # skip any symlinks
            test -f "$cert" -a ! -L "$cert" || continue
            
            # create a p11-kit header that set the label of the certificate
            # to the file name. This ensures that the certificate gets the same
            # name in ssl/certs as before
            base_name="${cert##*/}"
            (
            cat <<EOF
# created by ca-certificates from
# $cert
[p11-kit-object-v1]
class: certificate
label: "${base_name%.pem}"
trusted: true
EOF
            cat $cert
            ) > "%{admin_trust_dir}/$base_name"
        done
    
        mv %{openssl_certs_dir} %{openssl_certs_dir}.rpmnew
    fi
    ln -s %{_localstatedir}/lib/ca-certificates/openssl %{openssl_certs_dir}
    chown -h qsys %{openssl_certs_dir}
fi


%post -p %{_bindir}/bash
%{_bindir}/update-ca-certificates || :


%files
%defattr(-, qsys, *none)

%{_bindir}/update-ca-certificates

%{_sysconfdir}/ca-certificates
%{_libdir}/ca-certificates
%dir %{_localstatedir}/lib/ca-certificates

%{admin_trust_dir}
%{package_trust_dir}

%{openssl_certs_dir}
%{openssl_cert_pem}

%{_mandir}/man8/update-ca-certificates.8*

%changelog
* Mon Aug 01 2022 Kevin Adler <kadler@us.ibm.com> - 2_git20170807.10b2785
- Move README out of anchors directory

* Thu Jul 21 2022 Abdirahim Musse <abdirahim.musse@ibm.com> - 2_git20170807.10b2785
- Fix cadir path in 50-openssl.run

* Tue Jul 12 2022 Abdirahim Musse <abdirahim.musse@ibm.com> - 2_git20170807.10b2785
- Resolve default openssl certfile to correct location

* Tue Dec 07 2021 Mark Irish <mirish@ibm.com> - 2_git20170807.10b2785
- Take ownership of admin and package trust directories from p11-kit
- Add readme for using trust directories

* Thu Dec 3 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 2_git20170807.10b2785
- Ship certbundle.run to enable legacy curl-style certificate bundle

* Wed May 27 2020 Kevin Adler <kadler@us.ibm.com> - 2_git20170807.10b2785
- Use generic paths for man and info pages to allow for compression

* Thu May 16 2019 Yun Xiang <bjxiangy@cn.ibm.com>
- Fix missing directory /QOpenSys/var/lib/ca-certificates

* Thu May 09 2019 Kevin Adler <kadler@us.ibm.com>
- Change numbering scheme because IBM file server can't handle a + in the name
